import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i4 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i2 from '@angular/material/legacy-form-field';
import { MatLegacyFormFieldModule } from '@angular/material/legacy-form-field';
import * as i5 from '@angular/material/legacy-input';
import { MatLegacyInputModule } from '@angular/material/legacy-input';
import * as i3 from '@angular/material/legacy-slide-toggle';
import { MatLegacySlideToggleModule } from '@angular/material/legacy-slide-toggle';
import { CreateNoteDtoVisibilityEnum } from '@smallstack/axios-api-client';
import { LoadingElementDirective } from '@smallstack/common-components';
import { I18nComponent } from '@smallstack/i18n-components';
import * as i1 from '@smallstack/user-components';
import { filterNullish, TextReplacer } from '@smallstack/utils';
import { BaseWidgetComponent } from '@smallstack/widget-core';
import { combineLatest, map } from 'rxjs';

class CreateNoteWidgetComponent extends BaseWidgetComponent {
    constructor(noteStore) {
        super();
        this.noteStore = noteStore;
        this.VISIBILITY = CreateNoteDtoVisibilityEnum;
        this.createNote = { content: "", visibility: this.VISIBILITY.Public, target: {} };
        this.subscription.add(combineLatest([this.data$, this.context$])
            .pipe(filterNullish({ filterEmptyObjects: true }), map(([data, context]) => {
            if (data.targetId)
                this.createNote.target.id = TextReplacer.replace(data.targetId, context);
            if (data.targetType)
                this.createNote.target.type = data.targetType;
        }))
            .subscribe());
    }
    saveNote() {
        return async () => {
            const createdNote = await this.noteStore.create(this.createNote);
            await this.sendSocketData("noteCreated", createdNote);
        };
    }
    onPrivacyToggle() {
        if (this.createNote.visibility === this.VISIBILITY.Private)
            this.createNote.visibility = this.VISIBILITY.Public;
        else
            this.createNote.visibility = this.VISIBILITY.Private;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: CreateNoteWidgetComponent, deps: [{ token: i1.NoteStore }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.0", type: CreateNoteWidgetComponent, isStandalone: true, selector: "smallstack-create-note-widget", usesInheritance: true, ngImport: i0, template: "<div class=\"note-creation-body\">\n  <div>\n    <mat-form-field class=\"note-content-editor\">\n      <textarea name=\"content\" matInput [(ngModel)]=\"createNote.content\" placeholder=\"Neuen Notiz verfassen\"></textarea>\n    </mat-form-field>\n  </div>\n  <div class=\"flex flex-row justify-between items-center\">\n    <div>\n      <mat-slide-toggle\n        color=\"primary\"\n        [checked]=\"createNote.visibility === VISIBILITY.Private\"\n        (change)=\"onPrivacyToggle()\"\n      >\n        <smallstack-i18n data=\"@@notes.privatehint\"></smallstack-i18n>\n      </mat-slide-toggle>\n    </div>\n    <button [loadingFn]=\"saveNote()\" [disabled]=\"createNote.content.length === 0\" class=\"btn btn-outline btn-primary\">\n      <smallstack-i18n data=\"@@actions.addnote\"></smallstack-i18n>\n    </button>\n  </div>\n</div>\n", styles: [".note-content-editor{width:100%}.note-creation-body{min-width:300px;width:100%;margin-bottom:20px}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "ngmodule", type: MatLegacyFormFieldModule }, { kind: "component", type: i2.MatLegacyFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "ngmodule", type: MatLegacySlideToggleModule }, { kind: "component", type: i3.MatLegacySlideToggle, selector: "mat-slide-toggle", inputs: ["disabled", "disableRipple", "color", "tabIndex"], exportAs: ["matSlideToggle"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "directive", type: LoadingElementDirective, selector: "[loadingFn]", inputs: ["loadingFn", "isLoading"], exportAs: ["loadingFn"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i4.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "ngmodule", type: MatLegacyInputModule }, { kind: "directive", type: i5.MatLegacyInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", exportAs: ["matInput"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: CreateNoteWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-create-note-widget", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        CommonModule,
                        MatLegacyFormFieldModule,
                        MatLegacySlideToggleModule,
                        I18nComponent,
                        LoadingElementDirective,
                        FormsModule,
                        MatLegacyInputModule
                    ], template: "<div class=\"note-creation-body\">\n  <div>\n    <mat-form-field class=\"note-content-editor\">\n      <textarea name=\"content\" matInput [(ngModel)]=\"createNote.content\" placeholder=\"Neuen Notiz verfassen\"></textarea>\n    </mat-form-field>\n  </div>\n  <div class=\"flex flex-row justify-between items-center\">\n    <div>\n      <mat-slide-toggle\n        color=\"primary\"\n        [checked]=\"createNote.visibility === VISIBILITY.Private\"\n        (change)=\"onPrivacyToggle()\"\n      >\n        <smallstack-i18n data=\"@@notes.privatehint\"></smallstack-i18n>\n      </mat-slide-toggle>\n    </div>\n    <button [loadingFn]=\"saveNote()\" [disabled]=\"createNote.content.length === 0\" class=\"btn btn-outline btn-primary\">\n      <smallstack-i18n data=\"@@actions.addnote\"></smallstack-i18n>\n    </button>\n  </div>\n</div>\n", styles: [".note-content-editor{width:100%}.note-creation-body{min-width:300px;width:100%;margin-bottom:20px}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.NoteStore }]; } });

export { CreateNoteWidgetComponent };
//# sourceMappingURL=smallstack-todo-widgets-create-note-widget.component-daf1102f.mjs.map
