import { SocketDtoDirectionEnum, SocketDtoTypeEnum } from '@smallstack/axios-api-client';
import { AllWidgetTags, WidgetTag } from '@smallstack/widget-core';

const CreateNoteWidget = {
    name: "CreateNote",
    configuration: {
        templateName: "Notiz erstellen",
        templateDescription: "Mit diesem Widget können Notizen erstellt werden.",
        dataSchema: {
            type: "object",
            properties: {
                targetId: {
                    type: "string",
                    title: "Id der Ziel Entität",
                    description: "An welche Entität soll die Notiz gehängt werden?"
                },
                targetType: {
                    type: "string",
                    title: "Typ der Ziel Entität",
                    description: "Geben Sie hier den Datentyp an",
                    "x-schema-form": {
                        widget: "types"
                    }
                }
            }
        },
        icon: "note",
        tags: AllWidgetTags,
        sockets: [{ direction: SocketDtoDirectionEnum.Out, name: "noteCreated", type: SocketDtoTypeEnum.Object }]
    },
    component: () => import('./smallstack-todo-widgets-create-note-widget.component-daf1102f.mjs').then((m) => m.CreateNoteWidgetComponent)
};

const CONFIG_ONLY_MINE = "onlyMine";
const CONFIG_LINKED_ID_FILTER$1 = "linkedIdFilter";
const TodoAgendaWidget = {
    name: "TodoAgenda",
    configuration: {
        icon: "task",
        tags: AllWidgetTags,
        templateName: "Aufgaben Agenda",
        templateDescription: "Zeigt eine chronologische Agenda aller Aufgaben an",
        dataSchema: {
            type: "object",
            properties: {
                [CONFIG_ONLY_MINE]: {
                    title: "Zeige nur zugewiesene?",
                    type: "boolean",
                    description: "Falls aktiv, dann werden nur Aufgaben in der Agenda gezeigt, welche dem angemeldeten Benutzer oder niemandem zugewiesen sind."
                },
                [CONFIG_LINKED_ID_FILTER$1]: {
                    title: "Zeige nur für verknüpftes Objekt?",
                    type: "string",
                    description: "Falls aktiv, dann werden nur Aufgaben in der Agenda gezeigt, welche mit dem verknüpften Objekt verknüpft sind."
                }
            }
        }
    },
    component: () => import('./smallstack-todo-widgets-todo-agenda-widget.component-3d274bf7.mjs').then((m) => m.TodoAgendaWidgetComponent)
};

const WorklogWidget = {
    name: "Worklogs",
    configuration: {
        icon: "work",
        tags: [WidgetTag.APPLICATION, WidgetTag.CBO, WidgetTag.CMS, WidgetTag.PROJECT_DASHBOARD],
        templateName: "Arbeitsprotokolle",
        templateDescription: "Zeigt alle Arbeitsprotokolle des aktuell angemeldeten Benutzers.",
        dataSchema: {
            type: "object",
            properties: {
                showDeleteBtn: {
                    type: "boolean",
                    title: "Löschen Button anzeigen?"
                },
                showEditBtn: {
                    type: "boolean",
                    title: "Bearbeiten Button anzeigen?"
                }
            }
        }
    },
    component: () => import('./smallstack-todo-widgets-worklog-widget.component-144e93cd.mjs').then((m) => m.WorklogWidgetComponent)
};

const CONFIG_LINKED_ID_FILTER = "linkedIdFilter";
const CONFIG_BILLING_PARTY_ID_FILTER = "billingPartyIdFilter";
const AnytimeTodosWidget = {
    name: "AnytimeTodos",
    configuration: {
        templateName: '"Jederzeit" Aufgaben',
        templateDescription: "Zeigt alle Aufgaben an, die jederzeit ausgeführt und nicht an ein Datum gebunden sind.",
        icon: "task",
        dataSchema: {
            type: "object",
            properties: {
                [CONFIG_LINKED_ID_FILTER]: {
                    type: "string",
                    title: "Filter nach verlinkter ID",
                    description: "Wenn gesetzt, werden nur Aufgaben angezeigt, die mit dieser ID verlinkt sind."
                },
                [CONFIG_BILLING_PARTY_ID_FILTER]: {
                    type: "string",
                    title: "Filter nach verlinkter Rechnungspartei",
                    description: "Wenn gesetzt, werden nur Aufgaben angezeigt, die mit dieser Rechnungspartei verlinkt sind."
                }
            }
        }
    },
    component: () => import('./smallstack-todo-widgets-anytime-todos-widget.component-5864d04e.mjs').then((m) => m.AnytimeTodosWidgetComponent)
};

function addTodoWidgets(widgetRegistry) {
    widgetRegistry.addWidget(TodoAgendaWidget);
    widgetRegistry.addWidget(CreateNoteWidget);
    widgetRegistry.addWidget(WorklogWidget);
    widgetRegistry.addWidget(AnytimeTodosWidget);
}

/**
 * Generated bundle index. Do not edit.
 */

export { CONFIG_ONLY_MINE as C, CONFIG_LINKED_ID_FILTER$1 as a, CONFIG_LINKED_ID_FILTER as b, CONFIG_BILLING_PARTY_ID_FILTER as c, addTodoWidgets as d };
//# sourceMappingURL=smallstack-todo-widgets-smallstack-todo-widgets-4b2fd608.mjs.map
