import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i3 from '@angular/router';
import { SchedulingRuleDtoPatternEnum } from '@smallstack/axios-api-client';
import * as i2 from '@smallstack/i18n-components';
import { I18nComponent, DateComponent } from '@smallstack/i18n-components';
import { LoaderComponent } from '@smallstack/store-components';
import { IconComponent } from '@smallstack/theme-components';
import * as i1 from '@smallstack/todo-components';
import { generateNextDatesUntil, TodoListEntryComponent, TodoTemplateListEntryComponent } from '@smallstack/todo-components';
import { TypeModelComponent } from '@smallstack/type-components';
import { replaceVariables, ONE_DAY, ONE_HOUR, getGoogleMapsNavigationUrl } from '@smallstack/utils';
import { BaseWidgetComponent } from '@smallstack/widget-core';
import { subDays, startOfDay, endOfDay, format, addDays } from 'date-fns';
import { mergeMap, combineLatest, map } from 'rxjs';
import { C as CONFIG_ONLY_MINE, a as CONFIG_LINKED_ID_FILTER } from './smallstack-todo-widgets-smallstack-todo-widgets-4b2fd608.mjs';

class TodoAgendaWidgetComponent extends BaseWidgetComponent {
    constructor(todoTemplateStore, myTodoTemplateStore, todoStore, myTodoStore, notificationService, translationStore, activatedRoute) {
        super();
        this.todoTemplateStore = todoTemplateStore;
        this.myTodoTemplateStore = myTodoTemplateStore;
        this.todoStore = todoStore;
        this.myTodoStore = myTodoStore;
        this.notificationService = notificationService;
        this.translationStore = translationStore;
        this.activatedRoute = activatedRoute;
        this.agendaDays$ = this.getContextReplacedData$(CONFIG_ONLY_MINE).pipe(mergeMap((onlyMine) => {
            this.mineOrGlobalTodoStore = onlyMine ? this.myTodoStore : this.todoStore;
            this.mineOrGlobalTodoTemplateStore = onlyMine ? this.myTodoTemplateStore : this.todoTemplateStore;
            return combineLatest([
                this.mineOrGlobalTodoTemplateStore.preload$(),
                this.mineOrGlobalTodoStore.preload$(),
                this.data$,
                this.context$
            ]);
        }), 
        // filter by todoTemplate.billingPositions.billingParties.linkedId
        map(([todoTemplates, todos, data, context]) => {
            if (data[CONFIG_LINKED_ID_FILTER]) {
                const linkedId = replaceVariables(data[CONFIG_LINKED_ID_FILTER], {
                    ...context,
                    queryParams: this.activatedRoute.snapshot.queryParams
                });
                const filteredTodoTemplates = todoTemplates.filter((t) => {
                    for (const billingPosition of t.billingPositions) {
                        for (const billingParty of billingPosition.billingParties) {
                            if (billingParty.linkedId === linkedId)
                                return true;
                        }
                    }
                    return false;
                });
                return [filteredTodoTemplates, todos];
            }
            return [todoTemplates, todos];
        }), map(([todoTemplates, todos]) => {
            const agendaDays = [];
            const upcomingTodos = [];
            const overdueTodos = [];
            for (const todoTemplate of todoTemplates) {
                if (todoTemplate.schedulingRule?.pattern &&
                    todoTemplate.schedulingRule?.pattern !== SchedulingRuleDtoPatternEnum.Always) {
                    const nextDates = generateNextDatesUntil(todoTemplate.schedulingRule, {
                        from: Date.now(),
                        until: Date.now() + ONE_DAY * 14
                    });
                    for (const nextDate of nextDates) {
                        // try to find a todo
                        const todo = todos.find((t) => t.todoTemplateRefId === todoTemplate.id && t.startTime === nextDate);
                        if (!todo || todo.done !== true)
                            upcomingTodos.push({
                                startTime: nextDate,
                                endTime: nextDate + ONE_HOUR,
                                todoTemplate,
                                todo
                            });
                    }
                    const previousDates = generateNextDatesUntil(todoTemplate.schedulingRule, {
                        from: Date.now() - ONE_DAY * 14,
                        until: Date.now()
                    });
                    for (const previousDate of previousDates) {
                        // try to find a todo
                        const todo = todos.find((t) => t.todoTemplateRefId === todoTemplate.id && t.startTime === previousDate);
                        if (!todo || todo.done !== true)
                            overdueTodos.push({
                                startTime: previousDate,
                                endTime: previousDate + ONE_HOUR,
                                todoTemplate,
                                todo
                            });
                    }
                }
            }
            // get overdue todos of past 14 days
            for (let i = 14; i > 0; i--) {
                const day = subDays(new Date(), i);
                const dayStart = startOfDay(day).valueOf();
                const dayEnd = endOfDay(day).valueOf();
                const todoDates = overdueTodos
                    .filter((ut) => ut.startTime < dayEnd && ut.startTime >= dayStart)
                    .sort((a, b) => a.startTime - b.startTime);
                if (todoDates?.length > 0) {
                    todoDates.forEach((todoDate) => (todoDate.overdue = true));
                    agendaDays.push({
                        date: format(day, "EE, dd. MMM yyyy"),
                        todoDates
                    });
                }
            }
            // compute next 14 days
            for (let i = 0; i < 14; i++) {
                const day = addDays(new Date(), i);
                const dayStart = startOfDay(day).valueOf();
                const dayEnd = endOfDay(day).valueOf();
                const todoDates = upcomingTodos
                    .filter((ut) => ut.startTime < dayEnd && ut.startTime >= dayStart)
                    .sort((a, b) => a.startTime - b.startTime);
                if (todoDates?.length > 0) {
                    agendaDays.push({
                        date: format(day, "EE, dd. MMM yyyy"),
                        todoDates
                    });
                }
            }
            return agendaDays;
        }));
    }
    openGoogleMaps(address) {
        window.open(getGoogleMapsNavigationUrl(address), "_blank");
    }
    async createTodo(todo) {
        await this.mineOrGlobalTodoStore.put(todo);
        if (todo.done) {
            this.notificationService.popup.success("Aufgabe erledigt", "Die Aufgabe '" +
                this.translationStore.translate(todo.label) +
                "' ist vollständig erledigt und wurde nun aus der täglichen Agenda entfernt.");
        }
    }
    newTodoCreated() {
        void this.mineOrGlobalTodoTemplateStore.preload({ force: true });
        void this.mineOrGlobalTodoStore.preload({ force: true });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: TodoAgendaWidgetComponent, deps: [{ token: i1.TodoTemplateStore }, { token: i1.MyTodoTemplateStore }, { token: i1.TodoStore }, { token: i1.MyTodoStore }, { token: i2.NotificationService }, { token: i2.TranslationStore }, { token: i3.ActivatedRoute }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.0", type: TodoAgendaWidgetComponent, isStandalone: true, selector: "smallstack-todo-agenda-widget", usesInheritance: true, ngImport: i0, template: "<ng-container *ngIf=\"agendaDays$ | async as agendaDays; else loading\">\n  <div class=\"flex flex-col\">\n    <div *ngIf=\"!agendaDays || agendaDays.length === 0\" class=\"italic text-lg text-gray-400 text-center p-5\"\n      >Aktuell keine Aufgaben geplant</div\n    >\n    <div *ngFor=\"let todoDay of agendaDays; ngForTrackByJson\" class=\"mb-4\">\n      <div *ngIf=\"todoDay.fadeOut !== true\" class=\"text-lg my-2 flex flex-row gap-1 justify-start items-center\">\n        <smallstack-icon name=\"calendar\" size=\"24\"></smallstack-icon>\n        <span>{{ todoDay.date }}</span>\n      </div>\n      <div>\n        <div *ngIf=\"!todoDay.todoDates || todoDay.todoDates.length === 0\">\n          <div class=\"italic text-sm text-gray-400\">Keine Aufgaben an diesem Tag</div>\n        </div>\n        <ng-container *ngFor=\"let todoDate of todoDay.todoDates; ngForTrackByJson\">\n          <div\n            *ngIf=\"todoDate.invisible !== true\"\n            class=\"card card-bordered card-compact shadow mb-4 relative\"\n            [ngClass]=\"{\n              'border-l-8': todoDate.todo,\n              'border-l-success': todoDate.todo && !todoDate.todo.done,\n              'bg-error text-error-content': todoDate.overdue && !todoDate.todo,\n              'bg-white text-primary': !todoDate.overdue,\n              'border-l-primary': todoDate.todo?.done\n            }\"\n          >\n            <div\n              *ngIf=\"todoDate.fadeOut\"\n              class=\"absolute w-full h-full z-50 flex flex-row justify-center items-center content-center\"\n            >\n              <button (click)=\"todoDate.invisible = true\" class=\"btn btn-primary\">\n                Abgeschlossene Aufgabe ausblenden\n              </button>\n            </div>\n            <div\n              class=\"card-body\"\n              [ngClass]=\"{\n                'transition-opacity ease-out duration-1000 opacity-20': todoDate.fadeOut\n              }\"\n            >\n              <div class=\"card-title flex flex-row gap-1\">\n                <smallstack-icon\n                  *ngIf=\"todoDate.todo && todoDate.todo.done !== true\"\n                  name=\"play-button-circled--v1\"\n                  size=\"36\"\n                  class=\"animate-pulse\"\n                  theme=\"sf-regular\"\n                  themeColor=\"daisyTheme.success.bgColor\"\n                ></smallstack-icon>\n                <smallstack-icon\n                  *ngIf=\"todoDate.todo && todoDate.todo.done === true\"\n                  name=\"checked-checkbox\"\n                  size=\"36\"\n                  theme=\"sf-regular\"\n                  themeColor=\"daisyTheme.primary.bgColor\"\n                ></smallstack-icon>\n                <span *ngIf=\"todoDate.startTime\">\n                  {{ todoDate.startTime | date: \"HH:mm\" }}\n                </span>\n                <smallstack-i18n [data]=\"todoDate.todoTemplate.label\"></smallstack-i18n>\n              </div>\n              <div *ngIf=\"todoDate.overdue\" class=\"font-bold\"\n                >Aufgabe \u00FCberf\u00E4llig seit <smallstack-date [timestamp]=\"todoDate.endTime\"></smallstack-date\n              ></div>\n              <smallstack-i18n\n                *ngIf=\"todoDate.todoTemplate.description\"\n                [data]=\"todoDate.todoTemplate.description\"\n              ></smallstack-i18n>\n              <ng-container *ngIf=\"todoDate.todo; else startNew\">\n                <smallstack-todo-list-entry\n                  [todo]=\"todoDate.todo\"\n                  (saveFn)=\"createTodo($event)\"\n                ></smallstack-todo-list-entry>\n              </ng-container>\n              <ng-template #startNew>\n                <smallstack-todo-template-list-entry\n                  [todoTemplate]=\"todoDate.todoTemplate\"\n                  [fixedTime]=\"todoDate.startTime\"\n                  (createdTodo)=\"newTodoCreated()\"\n                ></smallstack-todo-template-list-entry>\n                <!-- <button\n                  [loadingFn]=\"createTodo(todoDate.todoTemplate, todoDate.startTime)\"\n                  class=\"btn btn-xl btn-block btn-primary\"\n                  >Aufgabe starten</button\n                > -->\n              </ng-template>\n            </div>\n          </div>\n        </ng-container>\n      </div>\n    </div>\n  </div>\n</ng-container>\n<ng-template #loading>\n  <smallstack-loader></smallstack-loader>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }, { kind: "pipe", type: i4.DatePipe, name: "date" }, { kind: "component", type: LoaderComponent, selector: "smallstack-loader", inputs: ["loading", "color", "size", "loadingText"] }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "badgeColor"], outputs: ["iconError"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "component", type: DateComponent, selector: "smallstack-date", inputs: ["timestamp", "format"] }, { kind: "component", type: TodoListEntryComponent, selector: "smallstack-todo-list-entry", inputs: ["todo", "editable", "showDueDate", "showChecklistEntries", "isRoot"], outputs: ["saveFn"] }, { kind: "component", type: TodoTemplateListEntryComponent, selector: "smallstack-todo-template-list-entry", inputs: ["todoTemplate", "fixedTime", "showPopoutLink"], outputs: ["createdTodo"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: TodoAgendaWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-todo-agenda-widget", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        CommonModule,
                        LoaderComponent,
                        IconComponent,
                        I18nComponent,
                        DateComponent,
                        TypeModelComponent,
                        TodoListEntryComponent,
                        TodoTemplateListEntryComponent
                    ], template: "<ng-container *ngIf=\"agendaDays$ | async as agendaDays; else loading\">\n  <div class=\"flex flex-col\">\n    <div *ngIf=\"!agendaDays || agendaDays.length === 0\" class=\"italic text-lg text-gray-400 text-center p-5\"\n      >Aktuell keine Aufgaben geplant</div\n    >\n    <div *ngFor=\"let todoDay of agendaDays; ngForTrackByJson\" class=\"mb-4\">\n      <div *ngIf=\"todoDay.fadeOut !== true\" class=\"text-lg my-2 flex flex-row gap-1 justify-start items-center\">\n        <smallstack-icon name=\"calendar\" size=\"24\"></smallstack-icon>\n        <span>{{ todoDay.date }}</span>\n      </div>\n      <div>\n        <div *ngIf=\"!todoDay.todoDates || todoDay.todoDates.length === 0\">\n          <div class=\"italic text-sm text-gray-400\">Keine Aufgaben an diesem Tag</div>\n        </div>\n        <ng-container *ngFor=\"let todoDate of todoDay.todoDates; ngForTrackByJson\">\n          <div\n            *ngIf=\"todoDate.invisible !== true\"\n            class=\"card card-bordered card-compact shadow mb-4 relative\"\n            [ngClass]=\"{\n              'border-l-8': todoDate.todo,\n              'border-l-success': todoDate.todo && !todoDate.todo.done,\n              'bg-error text-error-content': todoDate.overdue && !todoDate.todo,\n              'bg-white text-primary': !todoDate.overdue,\n              'border-l-primary': todoDate.todo?.done\n            }\"\n          >\n            <div\n              *ngIf=\"todoDate.fadeOut\"\n              class=\"absolute w-full h-full z-50 flex flex-row justify-center items-center content-center\"\n            >\n              <button (click)=\"todoDate.invisible = true\" class=\"btn btn-primary\">\n                Abgeschlossene Aufgabe ausblenden\n              </button>\n            </div>\n            <div\n              class=\"card-body\"\n              [ngClass]=\"{\n                'transition-opacity ease-out duration-1000 opacity-20': todoDate.fadeOut\n              }\"\n            >\n              <div class=\"card-title flex flex-row gap-1\">\n                <smallstack-icon\n                  *ngIf=\"todoDate.todo && todoDate.todo.done !== true\"\n                  name=\"play-button-circled--v1\"\n                  size=\"36\"\n                  class=\"animate-pulse\"\n                  theme=\"sf-regular\"\n                  themeColor=\"daisyTheme.success.bgColor\"\n                ></smallstack-icon>\n                <smallstack-icon\n                  *ngIf=\"todoDate.todo && todoDate.todo.done === true\"\n                  name=\"checked-checkbox\"\n                  size=\"36\"\n                  theme=\"sf-regular\"\n                  themeColor=\"daisyTheme.primary.bgColor\"\n                ></smallstack-icon>\n                <span *ngIf=\"todoDate.startTime\">\n                  {{ todoDate.startTime | date: \"HH:mm\" }}\n                </span>\n                <smallstack-i18n [data]=\"todoDate.todoTemplate.label\"></smallstack-i18n>\n              </div>\n              <div *ngIf=\"todoDate.overdue\" class=\"font-bold\"\n                >Aufgabe \u00FCberf\u00E4llig seit <smallstack-date [timestamp]=\"todoDate.endTime\"></smallstack-date\n              ></div>\n              <smallstack-i18n\n                *ngIf=\"todoDate.todoTemplate.description\"\n                [data]=\"todoDate.todoTemplate.description\"\n              ></smallstack-i18n>\n              <ng-container *ngIf=\"todoDate.todo; else startNew\">\n                <smallstack-todo-list-entry\n                  [todo]=\"todoDate.todo\"\n                  (saveFn)=\"createTodo($event)\"\n                ></smallstack-todo-list-entry>\n              </ng-container>\n              <ng-template #startNew>\n                <smallstack-todo-template-list-entry\n                  [todoTemplate]=\"todoDate.todoTemplate\"\n                  [fixedTime]=\"todoDate.startTime\"\n                  (createdTodo)=\"newTodoCreated()\"\n                ></smallstack-todo-template-list-entry>\n                <!-- <button\n                  [loadingFn]=\"createTodo(todoDate.todoTemplate, todoDate.startTime)\"\n                  class=\"btn btn-xl btn-block btn-primary\"\n                  >Aufgabe starten</button\n                > -->\n              </ng-template>\n            </div>\n          </div>\n        </ng-container>\n      </div>\n    </div>\n  </div>\n</ng-container>\n<ng-template #loading>\n  <smallstack-loader></smallstack-loader>\n</ng-template>\n" }]
        }], ctorParameters: function () { return [{ type: i1.TodoTemplateStore }, { type: i1.MyTodoTemplateStore }, { type: i1.TodoStore }, { type: i1.MyTodoStore }, { type: i2.NotificationService }, { type: i2.TranslationStore }, { type: i3.ActivatedRoute }]; } });

export { TodoAgendaWidgetComponent };
//# sourceMappingURL=smallstack-todo-widgets-todo-agenda-widget.component-3d274bf7.mjs.map
